@@ -17,6 +17,8 @@ my $socks_proxy;
 my $socks_port;
 my $socks_id;
 my $no_dns;
+my $ip6;
+my $usessl;
 
 GetOptions(
 "nick=s" => \$nick,
@@ -29,14 +31,17 @@ GetOptions(
 "socksuser=s" => \$socks_id,
 "ircname=s" => \$ircname,
 "nodns" => \$no_dns,
+"ip6" => \$ip6,
+"usessl" => \$usessl,
 );
 
 die unless $nick and $server;
 print "$nick $server\n";
 
-my $irc = POE::Component::IRC::State->spawn( Nick => $nick, Server => $server, Port => $port, Ircname => $ircname, Username => $user, Password => $password, socks_proxy => $socks_proxy, socks_port => $socks_port, socks_id => $socks_id, NoDNS => $no_dns );
+my $irc = POE::Component::IRC::State->spawn( Nick => $nick, Server => $server, Port => $port, Ircname => $ircname, Username => $user, Password => $password,
+                                             socks_proxy => $socks_proxy, socks_port => $socks_port, socks_id => $socks_id, NoDNS => $no_dns, useipv6 => $ip6, UseSSL => $usessl );
 
-print STDOUT $irc->version(), "\n";
+print STDOUT $irc->VERSION(), "\n";
 
 POE::Session->create(
 	package_states => [
